'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["checkTrigger", "classPrefix", "errorFromContext", "formDefaultValue", "formValue", "formError", "fluid", "nestedField", "layout", "model", "readOnly", "plaintext", "className", "children", "disabled", "onSubmit", "onReset", "onCheck", "onError", "onChange"];
import React from 'react';
import PropTypes from 'prop-types';
import { SchemaModel } from 'schema-typed';
import { FormValueProvider, FormProvider } from "./FormContext.js";
import FormControl from "../FormControl/index.js";
import FormControlLabel from "../FormControlLabel/index.js";
import FormErrorMessage from "../FormErrorMessage/index.js";
import FormGroup from "../FormGroup/index.js";
import FormHelpText from "../FormHelpText/index.js";
import { useEventCallback } from "../internals/hooks/index.js";
import { oneOf } from "../internals/propTypes/index.js";
import useSchemaModel from "./hooks/useSchemaModel.js";
import useFormValidate from "./hooks/useFormValidate.js";
import useFormValue from "./hooks/useFormValue.js";
import useFormClassNames from "./hooks/useFormClassNames.js";
import useFormRef from "./hooks/useFormRef.js";
var defaultSchema = SchemaModel({});

/**
 * The `Form` component is a form interface for collecting and validating user input.
 * @see https://rsuitejs.com/components/form
 */
var Form = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$checkTrigger = props.checkTrigger,
    checkTrigger = _props$checkTrigger === void 0 ? 'change' : _props$checkTrigger,
    _props$classPrefix = props.classPrefix,
    classPrefix = _props$classPrefix === void 0 ? 'form' : _props$classPrefix,
    _props$errorFromConte = props.errorFromContext,
    errorFromContext = _props$errorFromConte === void 0 ? true : _props$errorFromConte,
    _props$formDefaultVal = props.formDefaultValue,
    formDefaultValue = _props$formDefaultVal === void 0 ? {} : _props$formDefaultVal,
    controlledFormValue = props.formValue,
    controlledFormError = props.formError,
    fluid = props.fluid,
    _props$nestedField = props.nestedField,
    nestedField = _props$nestedField === void 0 ? false : _props$nestedField,
    _props$layout = props.layout,
    layout = _props$layout === void 0 ? 'vertical' : _props$layout,
    _props$model = props.model,
    formModel = _props$model === void 0 ? defaultSchema : _props$model,
    readOnly = props.readOnly,
    plaintext = props.plaintext,
    className = props.className,
    children = props.children,
    disabled = props.disabled,
    onSubmit = props.onSubmit,
    onReset = props.onReset,
    onCheck = props.onCheck,
    onError = props.onError,
    onChange = props.onChange,
    rest = _objectWithoutPropertiesLoose(props, _excluded);
  var _useSchemaModel = useSchemaModel(formModel),
    getCombinedModel = _useSchemaModel.getCombinedModel,
    pushFieldRule = _useSchemaModel.pushFieldRule,
    removeFieldRule = _useSchemaModel.removeFieldRule;
  var _useFormValue = useFormValue(controlledFormValue, {
      formDefaultValue: formDefaultValue,
      nestedField: nestedField
    }),
    formValue = _useFormValue.formValue,
    onRemoveValue = _useFormValue.onRemoveValue,
    setFieldValue = _useFormValue.setFieldValue,
    resetFormValue = _useFormValue.resetFormValue;
  var formValidateProps = {
    formValue: formValue,
    getCombinedModel: getCombinedModel,
    onCheck: onCheck,
    onError: onError,
    nestedField: nestedField
  };
  var _useFormValidate = useFormValidate(controlledFormError, formValidateProps),
    formError = _useFormValidate.formError,
    setFieldError = _useFormValidate.setFieldError,
    onRemoveError = _useFormValidate.onRemoveError,
    check = _useFormValidate.check,
    checkAsync = _useFormValidate.checkAsync,
    checkForField = _useFormValidate.checkForField,
    checkForFieldAsync = _useFormValidate.checkForFieldAsync,
    cleanErrors = _useFormValidate.cleanErrors,
    resetErrors = _useFormValidate.resetErrors,
    cleanErrorForField = _useFormValidate.cleanErrorForField;
  var classes = useFormClassNames({
    classPrefix: classPrefix,
    className: className,
    fluid: fluid,
    layout: layout,
    readOnly: readOnly,
    plaintext: plaintext,
    disabled: disabled
  });
  var submit = useEventCallback(function (event) {
    // Check the form before submitting
    if (check()) {
      onSubmit === null || onSubmit === void 0 ? void 0 : onSubmit(formValue, event);
    }
  });
  var reset = useEventCallback(function (event) {
    resetErrors();
    onReset === null || onReset === void 0 ? void 0 : onReset(resetFormValue(), event);
  });
  var handleSubmit = useEventCallback(function (event) {
    var _event$preventDefault, _event$stopPropagatio;
    event === null || event === void 0 ? void 0 : (_event$preventDefault = event.preventDefault) === null || _event$preventDefault === void 0 ? void 0 : _event$preventDefault.call(event);
    event === null || event === void 0 ? void 0 : (_event$stopPropagatio = event.stopPropagation) === null || _event$stopPropagatio === void 0 ? void 0 : _event$stopPropagatio.call(event);

    // Prevent submission when the form is disabled, readOnly, or plaintext
    if (disabled || readOnly || plaintext) {
      return;
    }
    submit();
  });
  var handleReset = useEventCallback(function (event) {
    var _event$preventDefault2, _event$stopPropagatio2;
    event === null || event === void 0 ? void 0 : (_event$preventDefault2 = event.preventDefault) === null || _event$preventDefault2 === void 0 ? void 0 : _event$preventDefault2.call(event);
    event === null || event === void 0 ? void 0 : (_event$stopPropagatio2 = event.stopPropagation) === null || _event$stopPropagatio2 === void 0 ? void 0 : _event$stopPropagatio2.call(event);

    // Prevent reset when the form is disabled, readOnly, or plaintext
    if (disabled || readOnly || plaintext) {
      return;
    }
    reset(event);
  });
  var imperativeMethods = {
    check: check,
    checkForField: checkForField,
    checkAsync: checkAsync,
    checkForFieldAsync: checkForFieldAsync,
    cleanErrors: cleanErrors,
    cleanErrorForField: cleanErrorForField,
    reset: reset,
    resetErrors: resetErrors,
    submit: submit
  };
  var formRef = useFormRef(ref, {
    imperativeMethods: imperativeMethods
  });
  var removeFieldValue = useEventCallback(function (name) {
    var formValue = onRemoveValue(name);
    onChange === null || onChange === void 0 ? void 0 : onChange(formValue);
  });
  var removeFieldError = useEventCallback(function (name) {
    onRemoveError(name);
  });
  var onFieldError = useEventCallback(function (name, checkResult) {
    setFieldError(name, checkResult);
  });
  var onFieldSuccess = useEventCallback(function (name) {
    removeFieldError(name);
  });
  var onFieldChange = useEventCallback(function (name, value, event) {
    var nextFormValue = setFieldValue(name, value);
    onChange === null || onChange === void 0 ? void 0 : onChange(nextFormValue, event);
  });
  var formContextValue = {
    errorFromContext: errorFromContext,
    checkTrigger: checkTrigger,
    plaintext: plaintext,
    readOnly: readOnly,
    disabled: disabled,
    formError: formError,
    nestedField: nestedField,
    pushFieldRule: pushFieldRule,
    getCombinedModel: getCombinedModel,
    removeFieldValue: removeFieldValue,
    removeFieldError: removeFieldError,
    removeFieldRule: removeFieldRule,
    onFieldSuccess: onFieldSuccess,
    onFieldChange: onFieldChange,
    onFieldError: onFieldError
  };
  return /*#__PURE__*/React.createElement("form", _extends({}, rest, {
    ref: formRef,
    onSubmit: handleSubmit,
    onReset: handleReset,
    className: classes
  }), /*#__PURE__*/React.createElement(FormProvider, {
    value: formContextValue
  }, /*#__PURE__*/React.createElement(FormValueProvider, {
    value: formValue
  }, children)));
});
Form.Control = FormControl;
Form.ControlLabel = FormControlLabel;
Form.ErrorMessage = FormErrorMessage;
Form.Group = FormGroup;
Form.HelpText = FormHelpText;
Form.displayName = 'Form';
Form.propTypes = {
  className: PropTypes.string,
  classPrefix: PropTypes.string,
  children: PropTypes.node,
  errorFromContext: PropTypes.bool,
  layout: oneOf(['horizontal', 'vertical', 'inline']),
  fluid: PropTypes.bool,
  formValue: PropTypes.object,
  formDefaultValue: PropTypes.object,
  formError: PropTypes.object,
  checkTrigger: oneOf(['change', 'blur', 'none']),
  onChange: PropTypes.func,
  onError: PropTypes.func,
  onCheck: PropTypes.func,
  onSubmit: PropTypes.func,
  model: PropTypes.any,
  readOnly: PropTypes.bool,
  plaintext: PropTypes.bool,
  disabled: PropTypes.bool
};
export default Form;